MyPosPaymentResponse class
Constructors
- MyPosPaymentResponse({String? reference_number, String? cardholder_name, String? date_time, String? pan, String? pan_hash, int? status, String? status_text, String? card_brand, String? card_entry_mode, String? response_code, String? authorization_code, bool? signature_required, String? TSI, String? TVR, String? AID, String? STAN, String? CVM, String? application_name, bool? transaction_approved, bool? dcc_available, double? amount_dcc, String? currency_dcc, double? exchange_rate, String? TID, bool? update_pending, String? resp_code, String? expire_date})
-
const
-
MyPosPaymentResponse.fromMap(Map<
String, dynamic> m) -
factory
Properties
- AID → String?
-
final
- amount_dcc → double?
-
final
- application_name → String?
-
final
-
final
- card_brand → String?
-
final
- card_entry_mode → String?
-
final
- cardholder_name → String?
-
final
- currency_dcc → String?
-
final
- CVM → String?
-
final
- date_time → String?
-
final
- dcc_available → bool?
-
final
- exchange_rate → double?
-
final
- expire_date → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pan → String?
-
final
- pan_hash → String?
-
final
- reference_number → String?
-
final
- resp_code → String?
-
final
- response_code → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature_required → bool?
-
final
- STAN → String?
-
final
- status → int?
-
final
- status_text → String?
-
final
- TID → String?
-
final
- transaction_approved → bool?
-
final
- TSI → String?
-
final
- TVR → String?
-
final
- update_pending → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited